---
search:
  exclude: true
---
# コード例

[repo](https://github.com/openai/openai-agents-python/tree/main/examples) の examples セクションで、SDK の多様なサンプル実装をご覧ください。これらのコード例は、さまざまなパターンや機能を示す複数の カテゴリー に整理されています。


## カテゴリー

- **[agent_patterns](https://github.com/openai/openai-agents-python/tree/main/examples/agent_patterns):**
  このカテゴリーの例では、次のような一般的な エージェント の設計パターンを示します

    - 決定論的なワークフロー
    - ツールとしての エージェント
    - エージェント の並列実行

- **[basic](https://github.com/openai/openai-agents-python/tree/main/examples/basic):**
  このカテゴリーの例では、SDK の基礎的な機能を示します

    - 動的な system prompt
    - ストリーミング出力
    - ライフサイクルイベント

- **[tool examples](https://github.com/openai/openai-agents-python/tree/main/examples/tools):**
  Web 検索 や ファイル検索 などの OpenAI がホストするツール の実装方法を学び、
   それらを エージェント に統合します。

- **[model providers](https://github.com/openai/openai-agents-python/tree/main/examples/model_providers):**
  SDK で OpenAI 以外のモデルを使用する方法を探ります。

- **[handoffs](https://github.com/openai/openai-agents-python/tree/main/examples/handoffs):**
  エージェント のハンドオフの実用的な例をご覧ください。

- **[mcp](https://github.com/openai/openai-agents-python/tree/main/examples/mcp):**
  MCP で エージェント を構築する方法を学びます。

- **[customer_service](https://github.com/openai/openai-agents-python/tree/main/examples/customer_service)** と **[research_bot](https://github.com/openai/openai-agents-python/tree/main/examples/research_bot):**
  実運用での活用を想定した、さらに作り込まれた 2 つのコード例

    - **customer_service**: 航空会社向けのカスタマーサービスシステムの例。
    - **research_bot**: シンプルな ディープリサーチ のクローン。

- **[voice](https://github.com/openai/openai-agents-python/tree/main/examples/voice):**
  当社の TTS および STT モデルを使った音声 エージェント のコード例をご覧ください。

- **[realtime](https://github.com/openai/openai-agents-python/tree/main/examples/realtime):**
  SDK を使用してリアルタイム体験を構築する方法を示すコード例。